@@ -23,7 +23,6 @@ if fitz.VersionFitz != fitz.TOOLS.mupdf_version():
             % (fitz.VersionFitz, fitz.TOOLS.mupdf_version())
         )
 
-
 # copy functions to their respective fitz classes
 import fitz.utils
 
@@ -32,11 +31,15 @@ import fitz.utils
 # ------------------------------------------------------------------------------
 fitz.open = fitz.Document
 fitz.Document.getToC = fitz.utils.getToC
+fitz.Document.getTOC = fitz.utils.getToC
+fitz.Document.setToC = fitz.utils.setToC
+fitz.Document.setTOC = fitz.utils.setToC
+fitz.Document.setTOC_item = fitz.utils.setTOC_item
+fitz.Document.delTOC_item = fitz.utils.delTOC_item
 fitz.Document._do_links = fitz.utils.do_links
 fitz.Document.getPagePixmap = fitz.utils.getPagePixmap
 fitz.Document.getPageText = fitz.utils.getPageText
 fitz.Document.setMetadata = fitz.utils.setMetadata
-fitz.Document.setToC = fitz.utils.setToC
 fitz.Document.searchPageFor = fitz.utils.searchPageFor
 fitz.Document.newPage = fitz.utils.newPage
 fitz.Document.insertPage = fitz.utils.insertPage
@@ -53,26 +56,32 @@ fitz.Page.drawCurve = fitz.utils.drawCurve
 fitz.Page.drawLine = fitz.utils.drawLine
 fitz.Page.drawOval = fitz.utils.drawOval
 fitz.Page.drawPolyline = fitz.utils.drawPolyline
-fitz.Page.drawRect = fitz.utils.drawRect
 fitz.Page.drawQuad = fitz.utils.drawQuad
+fitz.Page.drawRect = fitz.utils.drawRect
 fitz.Page.drawSector = fitz.utils.drawSector
 fitz.Page.drawSquiggle = fitz.utils.drawSquiggle
 fitz.Page.drawZigzag = fitz.utils.drawZigzag
-fitz.Page.getImageBbox = fitz.utils.getImageBbox
+fitz.Page.getLinks = fitz.utils.getLinks
+fitz.Page.getPixmap = fitz.utils.getPixmap
+fitz.Page.getText = fitz.utils.getText
+fitz.Page.getTextbox = fitz.utils.getTextbox
+fitz.Page.getTextSelection = fitz.utils.getTextSelection
 fitz.Page.getTextBlocks = fitz.utils.getTextBlocks
 fitz.Page.getTextWords = fitz.utils.getTextWords
-fitz.Page.getLinks = fitz.utils.getLinks
-fitz.Page.getText = fitz.utils.getText
-fitz.Page.getPixmap = fitz.utils.getPixmap
+fitz.Page.insertImage = fitz.utils.insertImage
 fitz.Page.insertLink = fitz.utils.insertLink
-fitz.Page.insertTextbox = fitz.utils.insertTextbox
 fitz.Page.insertText = fitz.utils.insertText
+fitz.Page.insertTextbox = fitz.utils.insertTextbox
+fitz.Page.newShape = lambda x: fitz.utils.Shape(x)
 fitz.Page.searchFor = fitz.utils.searchFor
 fitz.Page.showPDFpage = fitz.utils.showPDFpage
-fitz.Page.insertImage = fitz.utils.insertImage
 fitz.Page.updateLink = fitz.utils.updateLink
-fitz.Page.newShape = lambda x: fitz.utils.Shape(x)
-
+fitz.Page.writeText = fitz.utils.writeText
+# ------------------------------------------------------------------------------
+# Annot
+# ------------------------------------------------------------------------------
+fitz.Annot.getText = fitz.utils.getText
+fitz.Annot.getTextbox = fitz.utils.getTextbox
 # ------------------------------------------------------------------------------
 # Rect
 # ------------------------------------------------------------------------------
@@ -85,6 +94,12 @@ fitz.Rect.getArea = fitz.utils.getRectArea
 fitz.IRect.getRectArea = fitz.utils.getRectArea
 fitz.IRect.getArea = fitz.utils.getRectArea
 
+# ------------------------------------------------------------------------------
+# IRect
+# ------------------------------------------------------------------------------
+fitz.TextWriter.fillTextbox = fitz.utils.fillTextbox
+
+
 fitz.__doc__ = """
 PyMuPDF %s: Python bindings for the MuPDF %s library.
 Version date: %s.
